multidim.models.GaussianMixtureClassifier.set_params — GDA Toolbox v1.0 Manual

# multidim.models.GaussianMixtureClassifier.set_params

`GaussianMixtureClassifier.` `set_params`(**params)

  Set the parameters of this estimator.

  The method works on simple estimators as well as on nested objects (such as pipelines). The latter have parameters of the form `<component>__<parameter>` so that it’s possible to update each component of a nested object.

  Returns: | self

#### Previous topic

multidim.models.GaussianMixtureClassifier.score

#### Next topic

timeseries.jagged